#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semigroupoids
version:              5.3.5
visibility:           public
id:                   semigroupoids-5.3.5-1KqOyQUo73K39xav9EUPfS
key:                  semigroupoids-5.3.5-1KqOyQUo73K39xav9EUPfS
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/semigroupoids
synopsis:             Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.

    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.

    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.

    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.

    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.

    Ideally the following relationships would hold:

    > Foldable ----> Traversable <--- Functor ------> Alt ---------> Plus           Semigroupoid
    >      |               |            |                              |                  |
    >      v               v            v                              v                  v
    > Foldable1 ---> Traversable1     Apply --------> Applicative -> Alternative      Category
    >                                   |               |              |                  |
    >                                   v               v              v                  v
    >                                 Bind ---------> Monad -------> MonadPlus          Arrow
    >

    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.

    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.

    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.

category:             Control, Comonads
abi:                  ca4a7676346fa55fd6c5a52a69fc1579
exposed:              True
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Traversable.Instances

import-dirs:          /usr/lib/ghc-9.0.1/site-local/semigroupoids-5.3.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/semigroupoids-5.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/semigroupoids-5.3.5
hs-libraries:         HSsemigroupoids-5.3.5-1KqOyQUo73K39xav9EUPfS
depends:
    base-4.15.0.0 base-orphans-0.8.4-9fpaSJ2QIBZKXeT93OZ3Tf
    bifunctors-5.5.11-Ej12bC5Bw276idmFYL5FWO
    comonad-5.0.8-ICbo0KzVh7C3UaaMEUo8A9 containers-0.6.4.1
    contravariant-1.5.3-9uWNjFwgxFqEvI9fWPdJzP
    distributive-0.6.2.1-HuJPEhTY9VEBsItJiVAf2r
    hashable-1.3.2.0-2IQ0Qtd2MN7HlUHlezOEDe
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 template-haskell-2.17.0.0
    transformers-0.5.6.2
    transformers-compat-0.6.6-58sHB8TcbOoDoX7hOb5YA0
    unordered-containers-0.2.14.0-F4OqjO0JqkT1fpEQ2fUdqU

haddock-interfaces:
    /usr/share/doc/haskell-semigroupoids/html/semigroupoids.haddock

haddock-html:         /usr/share/doc/haskell-semigroupoids/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

